@@ -1,12 +1,11 @@
 """Contains common boilerplate/repetitive code."""
 
-from . import attributes, hooks, language, observable, timeutils
+from . import attributes, hooks, observable, timeutils
 from .attributes import attrib, attrs
 
 __all__ = [
     "attributes",
     "hooks",
-    "language",
     "observable",
     "timeutils",
     "attrs",
