@@ -1,7 +1,5 @@
 """Manages the application configuration."""
 
-from typing import Optional
-
 from .boilerplate import attrs, hooks
 
 __all__ = [
@@ -17,9 +15,6 @@ class Config:
     verbose: bool = False
     """If enabled, print status/debugging information."""
 
-    locale: Optional[str] = None
-    """Force the application to use specified locale instead of the default."""
-
 
 config: Config = Config()
 """The current application configuration.
